@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2019 ImageMagick Studio LLC, a non-profit organization
+  Copyright @ 1999 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
 
   You may not use this file except in compliance with the License.  You may
@@ -18,7 +18,6 @@
 #ifndef MAGICKCORE_PIXEL_ACCESSOR_H
 #define MAGICKCORE_PIXEL_ACCESSOR_H
 
-#include <assert.h>
 #include "MagickCore/cache.h"
 #include "MagickCore/cache-view.h"
 #include "MagickCore/color.h"
@@ -35,7 +34,7 @@ extern "C" {
 
 static inline Quantum ClampPixel(const MagickRealType pixel)
 {
-  if (pixel < 0.0f)
+  if (pixel < 0.0)
     return((Quantum) 0);
   if (pixel >= (MagickRealType) QuantumRange)
     return((Quantum) QuantumRange);
@@ -60,8 +59,7 @@ static inline Quantum GetPixelAlpha(const Image *magick_restrict image,
   return(pixel[image->channel_map[AlphaPixelChannel].offset]);
 }
 
-static inline PixelTrait GetPixelAlphaTraits(
-  const Image *magick_restrict image)
+static inline PixelTrait GetPixelAlphaTraits(const Image *magick_restrict image)
 {
   return(image->channel_map[AlphaPixelChannel].traits);
 }
@@ -80,8 +78,7 @@ static inline Quantum GetPixelBlack(const Image *magick_restrict image,
   return(pixel[image->channel_map[BlackPixelChannel].offset]);
 }
 
-static inline PixelTrait GetPixelBlackTraits(
-  const Image *magick_restrict image)
+static inline PixelTrait GetPixelBlackTraits(const Image *magick_restrict image)
 {
   return(image->channel_map[BlackPixelChannel].traits);
 }
@@ -111,6 +108,8 @@ static inline PixelTrait GetPixelCbTraits(const Image *magick_restrict image)
 static inline Quantum GetPixelChannel(const Image *magick_restrict image,
   const PixelChannel channel,const Quantum *magick_restrict pixel)
 {
+  if ((size_t) channel >= MaxPixelChannels)
+    return((Quantum) 0);
   if (image->channel_map[channel].traits == UndefinedPixelTrait)
     return((Quantum) 0);
   return(pixel[image->channel_map[channel].offset]);
@@ -119,6 +118,8 @@ static inline Quantum GetPixelChannel(const Image *magick_restrict image,
 static inline PixelChannel GetPixelChannelChannel(
   const Image *magick_restrict image,const ssize_t offset)
 {
+  if ((offset < 0) || (offset >= MaxPixelChannels))
+    return(UndefinedPixelChannel);
   return(image->channel_map[offset].channel);
 }
 
@@ -131,6 +132,8 @@ static inline ssize_t GetPixelChannelOffset(const Image *magick_restrict image,
 static inline PixelTrait GetPixelChannelTraits(
   const Image *magick_restrict image,const PixelChannel channel)
 {
+  if ((size_t) channel >= MaxPixelChannels)
+    return(UndefinedPixelTrait);
   return(image->channel_map[channel].traits);
 }
 
@@ -139,14 +142,20 @@ static inline size_t GetPixelChannels(const Image *magick_restrict image)
   return(image->number_channels);
 }
 
-static inline Quantum GetPixelCompositeMask(const Image *magick_restrict image,
-  const Quantum *magick_restrict pixel)
+static inline Quantum GetPixelCompositeMask(
+  const Image *magick_restrict image,const Quantum *magick_restrict pixel)
 {
   if (image->channel_map[CompositeMaskPixelChannel].traits == UndefinedPixelTrait)
     return((Quantum) QuantumRange);
   return(pixel[image->channel_map[CompositeMaskPixelChannel].offset]);
 }
 
+static inline PixelTrait GetPixelCompositeMaskTraits(
+  const Image *magick_restrict image)
+{
+  return(image->channel_map[CompositeMaskPixelChannel].traits);
+}
+
 static inline Quantum GetPixelCr(const Image *magick_restrict image,
   const Quantum *magick_restrict pixel)
 {
@@ -186,8 +195,7 @@ static inline Quantum GetPixelGreen(const Image *magick_restrict image,
   return(pixel[image->channel_map[GreenPixelChannel].offset]);
 }
 
-static inline PixelTrait GetPixelGreenTraits(
-  const Image *magick_restrict image)
+static inline PixelTrait GetPixelGreenTraits(const Image *magick_restrict image)
 {
   return(image->channel_map[GreenPixelChannel].traits);
 }
@@ -200,8 +208,7 @@ static inline Quantum GetPixelIndex(const Image *magick_restrict image,
   return(pixel[image->channel_map[IndexPixelChannel].offset]);
 }
 
-static inline PixelTrait GetPixelIndexTraits(
-  const Image *magick_restrict image)
+static inline PixelTrait GetPixelIndexTraits(const Image *magick_restrict image)
 {
   return(image->channel_map[IndexPixelChannel].traits);
 }
@@ -214,25 +221,22 @@ static inline MagickRealType GetPixelInfoChannel(
     case RedPixelChannel: return(pixel_info->red);
     case GreenPixelChannel: return(pixel_info->green);
     case BluePixelChannel: return(pixel_info->blue);
-    case BlackPixelChannel: return(pixel_info->black);
-    case AlphaPixelChannel: return(pixel_info->alpha);
+    case BlackPixelChannel:
+    {
+      if (pixel_info->colorspace != CMYKColorspace)
+        return(0.0);
+      return(pixel_info->black);
+    }
+    case AlphaPixelChannel:
+    {
+      if (pixel_info->alpha_trait == UndefinedPixelTrait)
+        return(OpaqueAlpha);
+      return(pixel_info->alpha);
+    }
     case IndexPixelChannel: return(pixel_info->index);
-    default: return((MagickRealType) 0.0);
+    default: break;
   }
-}
-
-static inline double PerceptibleReciprocal(const double x)
-{
-  double
-    sign;
-
-  /*
-    Return 1/x where x is perceptible (not unlimited or infinitesimal).
-  */
-  sign=x < 0.0 ? -1.0 : 1.0;
-  if ((sign*x) >= MagickEpsilon)
-    return(1.0/x);
-  return(sign/MagickEpsilon);
+  return((MagickRealType) 0.0);
 }
 
 static inline MagickRealType GetPixelInfoLuma(
@@ -243,13 +247,13 @@ static inline MagickRealType GetPixelInfoLuma(
 
   if (pixel->colorspace == sRGBColorspace)
     {
-      intensity=(MagickRealType) (0.212656f*pixel->red+0.715158f*pixel->green+
-        0.072186f*pixel->blue);
+      intensity=(MagickRealType) (0.212656*pixel->red+0.715158*pixel->green+
+        0.072186*pixel->blue);
       return(intensity);
     }
-  intensity=(MagickRealType) (0.212656f*EncodePixelGamma(pixel->red)+
-    0.715158f*EncodePixelGamma(pixel->green)+
-    0.072186f*EncodePixelGamma(pixel->blue));
+  intensity=(MagickRealType) (0.212656*EncodePixelGamma(pixel->red)+
+    0.715158*EncodePixelGamma(pixel->green)+
+    0.072186*EncodePixelGamma(pixel->blue));
   return(intensity);
 }
 
@@ -261,13 +265,13 @@ static inline MagickRealType GetPixelInfoLuminance(
 
   if (pixel->colorspace != sRGBColorspace)
     {
-      intensity=(MagickRealType) (0.212656f*pixel->red+0.715158f*pixel->green+
-        0.072186f*pixel->blue);
+      intensity=(MagickRealType) (0.212656*pixel->red+0.715158*pixel->green+
+        0.072186*pixel->blue);
       return(intensity);
     }
-  intensity=(MagickRealType) (0.212656f*DecodePixelGamma(pixel->red)+
-    0.715158f*DecodePixelGamma(pixel->green)+
-    0.072186f*DecodePixelGamma(pixel->blue));
+  intensity=(MagickRealType) (0.212656*DecodePixelGamma(pixel->red)+
+    0.715158*DecodePixelGamma(pixel->green)+
+    0.072186*DecodePixelGamma(pixel->blue));
   return(intensity);
 }
 
@@ -283,16 +287,16 @@ static inline ssize_t GetPixelLabel(const Image *magick_restrict image,
   return((ssize_t) pixel[image->channel_map[LabelPixelChannel].offset]);
 }
 
-static inline MagickRealType GetPixelLuma(const Image *magick_restrict image,
-  const Quantum *magick_restrict pixel)
+static inline MagickRealType GetPixelLuma(
+  const Image *magick_restrict image,const Quantum *magick_restrict pixel)
 {
   MagickRealType
     intensity;
 
-  intensity=(MagickRealType) (
-    0.212656f*pixel[image->channel_map[RedPixelChannel].offset]+
-    0.715158f*pixel[image->channel_map[GreenPixelChannel].offset]+
-    0.072186f*pixel[image->channel_map[BluePixelChannel].offset]);
+  intensity=
+    0.212656*(MagickRealType) pixel[image->channel_map[RedPixelChannel].offset]+
+    0.715158*(MagickRealType) pixel[image->channel_map[GreenPixelChannel].offset]+
+    0.072186*(MagickRealType) pixel[image->channel_map[BluePixelChannel].offset];
   return(intensity);
 }
 
@@ -304,16 +308,16 @@ static inline MagickRealType GetPixelLuminance(
 
   if (image->colorspace != sRGBColorspace)
     {
-      intensity=(MagickRealType) (
-        0.212656f*pixel[image->channel_map[RedPixelChannel].offset]+
-        0.715158f*pixel[image->channel_map[GreenPixelChannel].offset]+
-        0.072186f*pixel[image->channel_map[BluePixelChannel].offset]);
+      intensity=
+        0.212656*(MagickRealType) pixel[image->channel_map[RedPixelChannel].offset]+
+        0.715158*(MagickRealType) pixel[image->channel_map[GreenPixelChannel].offset]+
+        0.072186*(MagickRealType) pixel[image->channel_map[BluePixelChannel].offset];
       return(intensity);
     }
-  intensity=(MagickRealType) (0.212656f*DecodePixelGamma((MagickRealType)
-    pixel[image->channel_map[RedPixelChannel].offset])+0.715158f*
+  intensity=(MagickRealType) (0.212656*DecodePixelGamma((MagickRealType)
+    pixel[image->channel_map[RedPixelChannel].offset])+0.715158*
     DecodePixelGamma((MagickRealType)
-    pixel[image->channel_map[GreenPixelChannel].offset])+0.072186f*
+    pixel[image->channel_map[GreenPixelChannel].offset])+0.072186*
     DecodePixelGamma((MagickRealType)
     pixel[image->channel_map[BluePixelChannel].offset]));
   return(intensity);
@@ -331,6 +335,19 @@ static inline PixelTrait GetPixelMagentaTraits(
   return(image->channel_map[MagentaPixelChannel].traits);
 }
 
+static inline Quantum GetPixelMeta(const Image *magick_restrict image,
+  const Quantum *magick_restrict pixel)
+{
+  if (image->channel_map[MetaPixelChannels].traits == UndefinedPixelTrait)
+    return(OpaqueAlpha);
+  return(pixel[image->channel_map[MetaPixelChannels].offset]);
+}
+
+static inline PixelTrait GetPixelMetaTraits(const Image *magick_restrict image)
+{
+  return(image->channel_map[MetaPixelChannels].traits);
+}
+
 static inline Quantum GetPixelReadMask(const Image *magick_restrict image,
   const Quantum *magick_restrict pixel)
 {
@@ -339,8 +356,18 @@ static inline Quantum GetPixelReadMask(const Image *magick_restrict image,
   return(pixel[image->channel_map[ReadMaskPixelChannel].offset]);
 }
 
-static inline Quantum GetPixelWriteMask(const Image *magick_restrict image,
-  const Quantum *magick_restrict pixel)
+static inline void GetPixelInfoRGBA(const Quantum red,const Quantum green,
+  const Quantum blue,const Quantum alpha,PixelInfo *magick_restrict pixel)
+{
+  GetPixelInfo((Image *) NULL,pixel);
+  pixel->red=red;
+  pixel->green=green;
+  pixel->blue=blue;
+  pixel->alpha=alpha;
+}
+
+static inline Quantum GetPixelWriteMask(
+  const Image *magick_restrict image,const Quantum *magick_restrict pixel)
 {
   if (image->channel_map[WriteMaskPixelChannel].traits == UndefinedPixelTrait)
     return((Quantum) QuantumRange);
@@ -411,14 +438,11 @@ static inline void GetPixelInfoPixel(const Image *magick_restrict image,
             pixel_info->black=(MagickRealType)
               pixel[image->channel_map[BlackPixelChannel].offset];
           if (image->channel_map[AlphaPixelChannel].traits != UndefinedPixelTrait)
-            {
-              pixel_info->alpha=(MagickRealType)
-                pixel[image->channel_map[AlphaPixelChannel].offset];
-              pixel_info->alpha_trait=BlendPixelTrait;
-            }
+            pixel_info->alpha=(MagickRealType)
+              pixel[image->channel_map[AlphaPixelChannel].offset];
           if (image->channel_map[IndexPixelChannel].traits != UndefinedPixelTrait)
             pixel_info->index=(MagickRealType)
-          pixel[image->channel_map[IndexPixelChannel].offset];
+              pixel[image->channel_map[IndexPixelChannel].offset];
         }
     }
 }
@@ -426,9 +450,17 @@ static inline void GetPixelInfoPixel(const Image *magick_restrict image,
 static inline PixelTrait GetPixelTraits(const Image *magick_restrict image,
   const PixelChannel channel)
 {
+  if ((size_t) channel >= MaxPixelChannels)
+    return(UndefinedPixelTrait);
   return(image->channel_map[channel].traits);
 }
 
+static inline PixelTrait GetPixelWriteMaskTraits(
+  const Image *magick_restrict image)
+{
+  return(image->channel_map[WriteMaskPixelChannel].traits);
+}
+
 static inline Quantum GetPixelY(const Image *magick_restrict image,
   const Quantum *magick_restrict pixel)
 {
@@ -454,7 +486,7 @@ static inline PixelTrait GetPixelYellowTraits(
 
 static inline MagickRealType AbsolutePixelValue(const MagickRealType x)
 {
-  return(x < 0.0f ? -x : x);
+  return(x < 0.0 ? -x : x);
 }
 
 static inline MagickBooleanType IsPixelAtDepth(const Quantum pixel,
@@ -466,11 +498,11 @@ static inline MagickBooleanType IsPixelAtDepth(const Quantum pixel,
   if (range == 0)
     return(MagickTrue);
 #if !defined(MAGICKCORE_HDRI_SUPPORT)
-  quantum=(Quantum) (((MagickRealType) QuantumRange*((QuantumAny)
-    (((MagickRealType) range*pixel)/QuantumRange+0.5)))/range+0.5);
+  quantum=(Quantum) (((double) QuantumRange*((QuantumAny) (((double) range*
+    pixel)/(double) QuantumRange+0.5)))/(double) range+0.5);
 #else
-  quantum=(Quantum) (((MagickRealType) QuantumRange*((QuantumAny)
-    (((MagickRealType) range*pixel)/QuantumRange+0.5)))/range);
+  quantum=(Quantum) (((double) QuantumRange*((QuantumAny) (((double) range*
+    (double) pixel)/(double) QuantumRange+0.5)))/(double) range);
 #endif
   return(pixel == quantum ? MagickTrue : MagickFalse);
 }
@@ -491,8 +523,8 @@ static inline MagickBooleanType IsPixelEquivalent(
     q->alpha;
   if (AbsolutePixelValue(alpha-beta) >= MagickEpsilon)
     return(MagickFalse);
-  if ((AbsolutePixelValue(alpha-TransparentAlpha) < MagickEpsilon) ||
-      (AbsolutePixelValue(beta-TransparentAlpha) < MagickEpsilon))
+  if ((AbsolutePixelValue(alpha-(MagickRealType) TransparentAlpha) < MagickEpsilon) ||
+      (AbsolutePixelValue(beta-(MagickRealType) TransparentAlpha) < MagickEpsilon))
     return(MagickTrue);  /* no color component if pixel is transparent */
   color=(MagickRealType) p[image->channel_map[RedPixelChannel].offset];
   if (AbsolutePixelValue(color-q->red) >= MagickEpsilon)
@@ -519,11 +551,12 @@ static inline MagickBooleanType IsPixelGray(const Image *magick_restrict image,
     green_blue,
     red_green;
 
-  red_green=(MagickRealType) pixel[image->channel_map[RedPixelChannel].offset]-
-    pixel[image->channel_map[GreenPixelChannel].offset];
-  green_blue=(MagickRealType)
-    pixel[image->channel_map[GreenPixelChannel].offset]-
-    pixel[image->channel_map[BluePixelChannel].offset];
+  red_green=
+    (MagickRealType) pixel[image->channel_map[RedPixelChannel].offset]-
+    (MagickRealType) pixel[image->channel_map[GreenPixelChannel].offset];
+  green_blue=
+    (MagickRealType) pixel[image->channel_map[GreenPixelChannel].offset]-
+    (MagickRealType) pixel[image->channel_map[BluePixelChannel].offset];
   if ((AbsolutePixelValue(red_green) < MagickEpsilon) &&
       (AbsolutePixelValue(green_blue) < MagickEpsilon))
     return(MagickTrue);
@@ -543,8 +576,8 @@ static inline MagickBooleanType IsPixelInfoEquivalent(
     q->alpha;
   if (AbsolutePixelValue(alpha-beta) >= MagickEpsilon)
     return(MagickFalse);
-  if ((AbsolutePixelValue(alpha-TransparentAlpha) < MagickEpsilon) ||
-      (AbsolutePixelValue(beta-TransparentAlpha) < MagickEpsilon))
+  if ((AbsolutePixelValue(alpha-(MagickRealType) TransparentAlpha) < MagickEpsilon) ||
+      (AbsolutePixelValue(beta-(MagickRealType) TransparentAlpha) < MagickEpsilon))
     return(MagickTrue);  /* no color component if pixel is transparent */
   if (AbsolutePixelValue(p->red-q->red) >= MagickEpsilon)
     return(MagickFalse);
@@ -570,13 +603,14 @@ static inline MagickBooleanType IsPixelMonochrome(
 
   red=(MagickRealType) pixel[image->channel_map[RedPixelChannel].offset];
   if ((AbsolutePixelValue(red) >= MagickEpsilon) &&
-      (AbsolutePixelValue(red-QuantumRange) >= MagickEpsilon))
+      (AbsolutePixelValue(red-(MagickRealType) QuantumRange) >= MagickEpsilon))
     return(MagickFalse);
-  red_green=(MagickRealType) pixel[image->channel_map[RedPixelChannel].offset]-
-    pixel[image->channel_map[GreenPixelChannel].offset];
-  green_blue=(MagickRealType)
-    pixel[image->channel_map[GreenPixelChannel].offset]-
-    pixel[image->channel_map[BluePixelChannel].offset];
+  red_green=
+    (MagickRealType) pixel[image->channel_map[RedPixelChannel].offset]-
+    (MagickRealType) pixel[image->channel_map[GreenPixelChannel].offset];
+  green_blue=
+    (MagickRealType) pixel[image->channel_map[GreenPixelChannel].offset]-
+    (MagickRealType) pixel[image->channel_map[BluePixelChannel].offset];
   if ((AbsolutePixelValue(red_green) < MagickEpsilon) &&
       (AbsolutePixelValue(green_blue) < MagickEpsilon))
     return(MagickTrue);
@@ -600,7 +634,7 @@ static inline MagickBooleanType IsPixelInfoMonochrome(
     red_green;
 
   if ((AbsolutePixelValue(pixel_info->red) >= MagickEpsilon) ||
-      (AbsolutePixelValue(pixel_info->red-QuantumRange) >= MagickEpsilon))
+      (AbsolutePixelValue(pixel_info->red-(MagickRealType) QuantumRange) >= MagickEpsilon))
     return(MagickFalse);
   red_green=pixel_info->red-pixel_info->green;
   green_blue=pixel_info->green-pixel_info->blue;
@@ -636,7 +670,7 @@ static inline void SetPixelb(const Image *magick_restrict image,
     pixel[image->channel_map[bPixelChannel].offset]=b;
 }
 
-static inline void SetPixelBackgoundColor(const Image *magick_restrict image,
+static inline void SetPixelBackgroundColor(const Image *magick_restrict image,
   Quantum *magick_restrict pixel)
 {
   ssize_t
@@ -659,6 +693,15 @@ static inline void SetPixelBackgoundColor(const Image *magick_restrict image,
       ClampToQuantum(image->background_color.alpha);
 }
 
+static inline void SetPixelBackgoundColor(const Image *magick_restrict image,
+  Quantum *magick_restrict pixel) magick_attribute((deprecated));
+
+static inline void SetPixelBackgoundColor(const Image *magick_restrict image,
+  Quantum *magick_restrict pixel)
+{
+  SetPixelBackgroundColor(image,pixel);
+}
+
 static inline void SetPixelBlack(const Image *magick_restrict image,
   const Quantum black,Quantum *magick_restrict pixel)
 {
@@ -697,6 +740,8 @@ static inline void SetPixelChannel(const Image *magick_restrict image,
   const PixelChannel channel,const Quantum quantum,
   Quantum *magick_restrict pixel)
 {
+  if ((size_t) channel >= MaxPixelChannels)
+    return;
   if (image->channel_map[channel].traits != UndefinedPixelTrait)
     pixel[image->channel_map[channel].offset]=quantum;
 }
@@ -705,8 +750,10 @@ static inline void SetPixelChannelAttributes(
   const Image *magick_restrict image,const PixelChannel channel,
   const PixelTrait traits,const ssize_t offset)
 {
-  assert((ssize_t) channel < MaxPixelChannels);
-  assert(offset < MaxPixelChannels);
+  if ((offset < 0) || (offset >= MaxPixelChannels))
+    return;
+  if ((size_t) channel >= MaxPixelChannels)
+    return;
   image->channel_map[offset].channel=channel;
   image->channel_map[channel].offset=offset;
   image->channel_map[channel].traits=traits;
@@ -715,6 +762,10 @@ static inline void SetPixelChannelAttributes(
 static inline void SetPixelChannelChannel(const Image *magick_restrict image,
   const PixelChannel channel,const ssize_t offset)
 {
+  if ((offset < 0) || (offset >= MaxPixelChannels))
+    return;
+  if ((size_t) channel >= MaxPixelChannels)
+    return;
   image->channel_map[offset].channel=channel;
   image->channel_map[channel].offset=offset;
 }
@@ -727,6 +778,8 @@ static inline void SetPixelChannels(Image *image,const size_t number_channels)
 static inline void SetPixelChannelTraits(Image *image,
   const PixelChannel channel,const PixelTrait traits)
 {
+  if ((size_t) channel >= MaxPixelChannels)
+    return;
   image->channel_map[channel].traits=traits;
 }
 
@@ -824,6 +877,17 @@ static inline void SetPixelMagentaTraits(Image *image,const PixelTrait traits)
   image->channel_map[MagentaPixelChannel].traits=traits;
 }
 
+static inline void SetPixelMeta(const Image *magick_restrict image,
+  const Quantum red,Quantum *magick_restrict pixel)
+{
+  pixel[image->channel_map[MetaPixelChannels].offset]=red;
+}
+
+static inline void SetPixelMetaTraits(Image *image,const PixelTrait traits)
+{
+  image->channel_map[MetaPixelChannels].traits=traits;
+}
+
 static inline void SetPixelReadMask(const Image *magick_restrict image,
   const Quantum mask,Quantum *magick_restrict pixel)
 {
@@ -831,13 +895,6 @@ static inline void SetPixelReadMask(const Image *magick_restrict image,
     pixel[image->channel_map[ReadMaskPixelChannel].offset]=mask;
 }
 
-static inline void SetPixelWriteMask(const Image *magick_restrict image,
-  const Quantum mask,Quantum *magick_restrict pixel)
-{
-  if (image->channel_map[WriteMaskPixelChannel].traits != UndefinedPixelTrait)
-    pixel[image->channel_map[WriteMaskPixelChannel].offset]=mask;
-}
-
 static inline void SetPixelMetacontentExtent(Image *image,const size_t extent)
 {
   image->metacontent_extent=extent;
@@ -861,6 +918,13 @@ static inline void SetPixelRedTraits(Image *image,const PixelTrait traits)
   image->channel_map[RedPixelChannel].traits=traits;
 }
 
+static inline void SetPixelWriteMask(const Image *magick_restrict image,
+  const Quantum mask,Quantum *magick_restrict pixel)
+{
+  if (image->channel_map[WriteMaskPixelChannel].traits != UndefinedPixelTrait)
+    pixel[image->channel_map[WriteMaskPixelChannel].offset]=mask;
+}
+
 static inline void SetPixelYellow(const Image *magick_restrict image,
   const Quantum yellow,Quantum *magick_restrict pixel)
 {
